package edu.wpi.banmqp.shimmer.sensor;

import java.io.ByteArrayInputStream;
import java.nio.ByteBuffer;
import java.nio.ByteOrder;

import edu.wpi.banmqp.shimmer.IShimmer;
import edu.wpi.banmqp.util.BANLog;

public abstract class SensorFactory {

	public static SensorMap generateSensorMap(byte[] rawData, IShimmer mote){
		SensorMap map = new SensorMap();
		ByteArrayInputStream stream = new ByteArrayInputStream(rawData);
		// Get number of sensors
		int numberOfSensors = stream.read();
		BANLog.d("SENSOR_MAP_GEN", numberOfSensors + " sensor(s)");
		// Loop through stream to construct each sensor
		for(int i = 0; i < numberOfSensors; i++){
			// First byte is sensor ID
			int sensorID = stream.read();
			BANLog.d("SENSOR_MAP_GEN", "Sensor ID: " + sensorID );
			//Next two bytes are the length of the sensor name
			byte[] nameLengthBuffer = new byte[2];
			stream.read(nameLengthBuffer, 0, 2);
			ByteBuffer buff = ByteBuffer.allocate(2);
			buff.order(ByteOrder.BIG_ENDIAN);
			buff.put(nameLengthBuffer);
			int nameLength = buff.getShort(0);
			BANLog.d("SENSOR_MAP_GEN", "Name Length: " + nameLength);
			StringBuilder name = new StringBuilder();
			// Get the sensor name one char at a time
			for(int j = 0; j < nameLength; j++){
				name.append((char) stream.read());
			}
			BANLog.d("SENSOR_MAP_GEN", "Sensor Name: " + name.toString());
			
			map.put(sensorID, new Sensor(sensorID, name.toString(), mote));
			
		}
		
		
		
		
		
		
		return map;
	}



}
